@@ -6,7 +6,7 @@ from .keys import bing_key
 
 
 class Bing(Base):
-    provider = 'Bing'
+    provider = 'bing'
     api = 'Bing Maps REST Services'
     url = 'http://dev.virtualearth.net/REST/v1/Locations'
     _description = 'The Bing™ Maps REST Services Application Programming Interface (API)\n'
@@ -28,12 +28,13 @@ class Bing(Base):
         # Initialize
         self._connect()
         self._parse(self.content)
-        self._test()
         self._json()
+        self.bbox
 
-    @property
-    def status_description(self):
-        return self._get_json_str('statusDescription')
+        # Bing catch errors
+        status = self._get_json_str('statusDescription')
+        if not status == 'OK':
+            self._error = status
 
     @property
     def lat(self):
@@ -72,7 +73,7 @@ class Bing(Base):
         return self._get_bbox(south, west, north, east)
 
     @property
-    def locality(self):
+    def city(self):
         return self._get_json_str('address-locality')
 
     @property
