@@ -28,12 +28,25 @@ def test_entry_points():
     geocoder.geolytica
     geocoder.canadapost
 
-def test_timezone():
-    g = geocoder.timezone(location)
+def test_google():
+    g = geocoder.google(location)
     assert g.ok
 
-"""
-UNSTABLE Providers
+def test_google_reverse():
+    g = geocoder.google(ottawa, method='reverse')
+    assert g.ok
+
+def test_bing():
+    g = geocoder.bing(location)
+    assert g.ok
+
+def test_bing_reverse():
+    g = geocoder.bing(ottawa, method='reverse')
+    assert g.ok
+    
+def test_opencage():
+    g = geocoder.opencage(location)
+    assert g.ok
 
 def test_yahoo():
     g = geocoder.yahoo(location)
@@ -43,12 +56,6 @@ def test_arcgis():
     g = geocoder.arcgis(location)
     assert g.ok
 
-"""
-
-def test_elevation():
-    g = geocoder.elevation(location)
-    assert g.ok
-
 def test_geolytica():
     g = geocoder.geolytica(address)
     assert g.ok
@@ -57,30 +64,6 @@ def test_canadapost():
     g = geocoder.canadapost(address)
     assert g.ok
 
-"""
-Not Working at the moment
-
-def test_canadapost_reverse():
-    g = geocoder.canadapost(ottawa, reverse=True)
-    assert g.ok
-
-"""
-
-def test_google():
-    g = geocoder.google(location)
-    assert g.ok
-
-def test_google_reverse():
-    g = geocoder.google(ottawa, reverse=True)
-    assert g.ok
-
-def test_bing():
-    g = geocoder.bing(location)
-    assert g.ok
-
-def test_bing_reverse():
-    g = geocoder.bing(ottawa, reverse=True)
-    assert g.ok
 
 def test_nokia():
     g = geocoder.nokia(location)
